@@ -33,8 +33,8 @@ import json
 # Tested using Pika 1.0.1, may not work correctly with earlier versions.
 import pika  # sudo pip3 install pika
 
-from asl_workflow_engine.logger import init_logging
-from asl_workflow_engine.messaging_exceptions import *
+from local_workflow_engine.logger import init_logging
+from local_workflow_engine.messaging_exceptions import *
 
 class Connection(object):
     def __init__(self, url="amqp://localhost:5672"):
