@@ -22,8 +22,8 @@ assert sys.version_info >= (3, 0)  # Bomb out if not running Python3
 
 
 import asyncio, importlib
-from asl_workflow_engine.logger import init_logging
-from asl_workflow_engine.messaging_exceptions import *
+from local_workflow_engine.logger import init_logging
+from local_workflow_engine.messaging_exceptions import *
 
 try:  # Attempt to use ujson if available https://pypi.org/project/ujson/
     import ujson as json
@@ -38,7 +38,7 @@ class EventDispatcher(object):
         :param config: Configuration dictionary
         :type config: dict
         """
-        self.logger = init_logging(log_name="asl_workflow_engine")
+        self.logger = init_logging(log_name="local_workflow_engine")
         self.logger.info("Creating EventDispatcher, using {} JSON parser".format(json.__name__))
 
         self.session = None  # Make session an attribute so it's visible from REST API
@@ -97,16 +97,16 @@ class EventDispatcher(object):
         )
 
         if name.endswith("_asyncio"):
-            self.name = "asl_workflow_engine." + name[:-8] + "_messaging_asyncio"
+            self.name = "local_workflow_engine." + name[:-8] + "_messaging_asyncio"
         else:
-            self.name = "asl_workflow_engine." + name + "_messaging"
+            self.name = "local_workflow_engine." + name + "_messaging"
 
         self.logger.info("Loading messaging module {}".format(self.name))
 
         # Load the module whose name is derived from the specified queue_type.
         try:
             print('name',self.name)
-            messaging = importlib.import_module("asl_workflow_engine.amqp_0_9_1_messaging")
+            messaging = importlib.import_module("local_workflow_engine.amqp_0_9_1_messaging")
             globals()["Connection"] = messaging.Connection
             globals()["Message"] = messaging.Message
         except ImportError as e:
@@ -160,7 +160,7 @@ class EventDispatcher(object):
             """
             The event_queue_producer is used to publish events corresponding
             to state transitions. This can publish to both the asl_workflow_events
-            queue that is shared by every asl_workflow_engine instance and also
+            queue that is shared by every local_workflow_engine instance and also
             the per-instance queues of each instance. The Message subject is
             used to select which queue the Message should be published to.
             """
@@ -176,9 +176,9 @@ class EventDispatcher(object):
 
             """
             The asl_workflow_events queue is a shared event queue, that is to
-            say every asl_workflow_engine instance receives events from this
+            say every local_workflow_engine instance receives events from this
             queue. This is used to publish StartExecution events to and is non-
-            exclusive so multiple asl_workflow_engine instances can consume from
+            exclusive so multiple local_workflow_engine instances can consume from
             it and will thus load-balance executions across multiple instances.
             """
             shared_queue = self.queue_name + '; {"node": {"durable": true}}'
@@ -192,7 +192,7 @@ class EventDispatcher(object):
 
             """
             the instance_event_consumer is an event queue that is set up for
-            each asl_workflow_engine instance. This should be an exclusive
+            each local_workflow_engine instance. This should be an exclusive
             queue such that only a single instance can consume from it. This
             queue is used for the remainder of the events for each execution.
             The idea of having an event queue per instance is because most
@@ -263,7 +263,7 @@ class EventDispatcher(object):
             """
             The event_queue_producer is used to publish events corresponding
             to state transitions. This can publish to both the asl_workflow_events
-            queue that is shared by every asl_workflow_engine instance and also
+            queue that is shared by every local_workflow_engine instance and also
             the per-instance queues of each instance. The Message subject is
             used to select which queue the Message should be published to.
             """
@@ -279,9 +279,9 @@ class EventDispatcher(object):
 
             """
             The asl_workflow_events queue is a shared event queue, that is to
-            say every asl_workflow_engine instance receives events from this
+            say every local_workflow_engine instance receives events from this
             queue. This is used to publish StartExecution events to and is non-
-            exclusive so multiple asl_workflow_engine instances can consume from
+            exclusive so multiple local_workflow_engine instances can consume from
             it and will thus load-balance executions across multiple instances.
             """
             shared_queue = self.queue_name + '; {"node": {"durable": true}}'
@@ -295,7 +295,7 @@ class EventDispatcher(object):
 
             """
             the instance_event_consumer is an event queue that is set up for
-            each asl_workflow_engine instance. This should be an exclusive
+            each local_workflow_engine instance. This should be an exclusive
             queue such that only a single instance can consume from it. This
             queue is used for the remainder of the events for each execution.
             The idea of having an event queue per instance is because most
@@ -420,7 +420,7 @@ class EventDispatcher(object):
         implementation details from the state engine.
 
         The start_execution field is used to select between publishing to the
-        event queue that is shared by all instances of asl_workflow_engine and
+        event queue that is shared by all instances of local_workflow_engine and
         the per instance queue.
 
         Setting content_type to application/json isn't necessary for correct
