@@ -41,7 +41,7 @@ import json, os, threading, time, uuid, weakref
 from collections import OrderedDict
 from collections.abc import Mapping, MutableMapping, Sequence
 
-from asl_workflow_engine.logger import init_logging
+from local_workflow_engine.logger import init_logging
 
 
 class JSONStore(MutableMapping):
@@ -59,7 +59,7 @@ class JSONStore(MutableMapping):
     def __init__(self, json_store_name, *args, **kwargs):
         self.json_store = json_store_name
 
-        self.logger = init_logging(log_name="asl_workflow_engine")
+        self.logger = init_logging(log_name="local_workflow_engine")
         self.logger.info("Creating JSONStore: {}".format(self.json_store))
 
         try:
@@ -239,7 +239,7 @@ class RedisStore(MutableMapping):
         daemon is used to set the thread listening for cache invalidation
         messages from the Redis server as a daemon or not.
         """
-        self.logger = init_logging(log_name="asl_workflow_engine")
+        self.logger = init_logging(log_name="local_workflow_engine")
         self.logger.info(
             "Creating {} {}: {}".format(key, self.__class__.__name__, url)
         )
