@@ -25,13 +25,13 @@ import os, time, uuid, opentracing, urllib.parse
 from datetime import datetime, timezone
 from aioprometheus import Counter, Histogram
 
-#from asl_workflow_engine.metrics_summary import TimeWindowSummary as Summary
-from asl_workflow_engine.metrics_summary import BasicSummary as Summary
+#from local_workflow_engine.metrics_summary import TimeWindowSummary as Summary
+from local_workflow_engine.metrics_summary import BasicSummary as Summary
 
-from asl_workflow_engine.logger import init_logging
-from asl_workflow_engine.open_tracing_factory import span_context, inject_span
-from asl_workflow_engine.messaging_exceptions import *
-from asl_workflow_engine.arn import *
+from local_workflow_engine.logger import init_logging
+from local_workflow_engine.open_tracing_factory import span_context, inject_span
+from local_workflow_engine.messaging_exceptions import *
+from local_workflow_engine.arn import *
 
 try:  # Attempt to use ujson if available https://pypi.org/project/ujson/
     import ujson as json
@@ -49,7 +49,7 @@ class TaskDispatcher(object):
         :param config: Configuration dictionary
         :type config: dict
         """
-        self.logger = init_logging(log_name="asl_workflow_engine")
+        self.logger = init_logging(log_name="local_workflow_engine")
         self.logger.info("Creating TaskDispatcher, using {} JSON parser".format(json.__name__))
 
         """
@@ -318,7 +318,7 @@ class TaskDispatcher(object):
         the Message implementation class on event_dispatcher globals(), so
         we can do the import of the Message class from event_dispatcher.
         """
-        from asl_workflow_engine.event_dispatcher import Message
+        from local_workflow_engine.event_dispatcher import Message
 
         """
         Use the value of the “Resource” field to determine the type of the task
